Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Claudius.Utils_gifSourceCommon utilies for screenshot and animation handling
timestamp prefix returns a filename with current timestamp
color_table_of_palette palette converts a palette to a GIF color table.
pad_palette_to_power_of_two table extends a color table to the next power of two, padding with black as needed, up to maximum 256 colors.
capture_frame screen framebuffer captures the current framebuffer contents as a compressed GIF image. Raises Failure if framebuffer contains invalid pixels.